@@ -25,6 +25,7 @@ from collections import defaultdict
 from json import dumps, loads
 from pathlib import Path
 import shutil
+import os
 from pkg_resources import resource_filename as _pkgres
 import re
 
@@ -47,17 +48,17 @@ from nipype.interfaces.base import (
     SimpleInterface,
 )
 from nipype.interfaces.io import add_traits
-from templateflow.api import templates as _get_template_list
+import templateflow as tf
 from ..utils.bids import _init_layout, relative_to_root
 from ..utils.images import set_consumables, unsafe_write_nifti_header_and_data
-from ..utils.misc import splitext as _splitext, _copy_any, unlink
+from ..utils.misc import _copy_any, unlink
 
 regz = re.compile(r"\.gz$")
 _pybids_spec = loads(Path(_pkgres("niworkflows", "data/nipreps.json")).read_text())
 BIDS_DERIV_ENTITIES = frozenset({e["name"] for e in _pybids_spec["entities"]})
 BIDS_DERIV_PATTERNS = tuple(_pybids_spec["default_path_patterns"])
 
-STANDARD_SPACES = _get_template_list()
+STANDARD_SPACES = tf.api.templates()
 LOGGER = logging.getLogger("nipype.interface")
 
 
@@ -457,7 +458,10 @@ space-MNI152NLin6Asym_res-01_desc-preproc_bold.json'
     >>> lines[1]
     '  "RepetitionTime": 0.75,'
 
-    >>> lines[2]
+    >>> lines[2]  # doctest: +ELLIPSIS
+    '  "Resolution": "Template MNI152NLin6Asym (1.0x1.0x1.0 mm^3)...'
+
+    >>> lines[3]
     '  "SkullStripped": true'
 
     >>> bids_dir = tmpdir / 'bidsroot' / 'sub-02' / 'ses-noanat' / 'func'
@@ -576,6 +580,17 @@ space-MNI152NLin6Asym_desc-preproc_bold.json'
         if out_entities.get("resolution") == "native" and out_entities.get("space"):
             out_entities.pop("resolution", None)
 
+        # Expand templateflow resolutions
+        resolution = out_entities.get("resolution")
+        space = out_entities.get("space")
+        if resolution:
+            # Standard spaces
+            if space in STANDARD_SPACES:
+                res = _get_tf_resolution(space, resolution)
+            else:  # TODO: Nonstandard?
+                res = "Unknown"
+            self._metadata['Resolution'] = res
+
         if len(set(out_entities["extension"])) == 1:
             out_entities["extension"] = out_entities["extension"][0]
 
@@ -613,6 +628,19 @@ space-MNI152NLin6Asym_desc-preproc_bold.json'
             self._results["out_file"].append(str(out_file))
             self._results["compression"].append(str(dest_file).endswith(".gz"))
 
+            # An odd but possible case is that an input file is in the location of
+            # the output and we have made no changes to it.
+            # The primary use case is pre-computed derivatives where the output
+            # directory will be filled in.
+            # From a provenance perspective, I would rather inputs and outputs be
+            # cleanly separated, but that is better handled by warnings at the CLI
+            # level than a crash in a datasink.
+            try:
+                if os.path.samefile(orig_file, out_file):
+                    continue
+            except FileNotFoundError:
+                pass
+
             # Set data and header iff changes need to be made. If these are
             # still None when it's time to write, just copy.
             new_data, new_header = None, None
@@ -710,21 +738,6 @@ space-MNI152NLin6Asym_desc-preproc_bold.json'
                 }
             )
             if self._metadata:
-                out_file = Path(self._results["out_file"][0])
-                # 1.3.x hack
-                # For dtseries, we have been generating weird non-BIDS JSON files.
-                # We can safely keep producing them to avoid breaking derivatives, but
-                # only the existing keys should keep going into them.
-                if out_file.name.endswith(".dtseries.nii"):
-                    legacy_metadata = {}
-                    for key in ("grayordinates", "space", "surface", "surface_density", "volume"):
-                        if key in self._metadata:
-                            legacy_metadata[key] = self._metadata.pop(key)
-                    if legacy_metadata:
-                        sidecar = out_file.parent / f"{_splitext(str(out_file))[0]}.json"
-                        unlink(sidecar, missing_ok=True)
-                        sidecar.write_text(dumps(legacy_metadata, sort_keys=True, indent=2))
-                # The future: the extension is the first . and everything after
                 sidecar = out_file.parent / f"{out_file.name.split('.', 1)[0]}.json"
                 unlink(sidecar, missing_ok=True)
                 sidecar.write_text(dumps(self._metadata, sort_keys=True, indent=2))
@@ -941,3 +954,38 @@ class BIDSFreeSurferDir(SimpleInterface):
                     )
 
         return runtime
+
+
+def _get_tf_resolution(space: str, resolution: str) -> str:
+    """
+    Query templateflow template information to elaborate on template resolution.
+
+    Examples
+    --------
+    >>> _get_tf_resolution('MNI152NLin2009cAsym', '01') # doctest: +ELLIPSIS
+    'Template MNI152NLin2009cAsym (1.0x1.0x1.0 mm^3)...'
+    >>> _get_tf_resolution('MNI152NLin2009cAsym', '1') # doctest: +ELLIPSIS
+    'Template MNI152NLin2009cAsym (1.0x1.0x1.0 mm^3)...'
+    >>> _get_tf_resolution('MNI152NLin2009cAsym', '10')
+    'Unknown'
+    """
+    metadata = tf.api.get_metadata(space)
+    resolutions = metadata.get('res', {})
+    res_meta = None
+
+    # Due to inconsistencies, resolution keys may or may not be zero-padded
+    padded_res = f'{str(resolution):0>2}'
+    for r in (resolution, padded_res):
+        if r in resolutions:
+            res_meta = resolutions[r]
+    if res_meta is None:
+        return "Unknown"
+
+    def _fmt_xyz(coords: list) -> str:
+        xyz = "x".join([str(c) for c in coords])
+        return f"{xyz} mm^3"
+
+    return (
+        f"Template {space} ({_fmt_xyz(res_meta['zooms'])}),"
+        f" curated by TemplateFlow {tf.__version__}"
+    )
